@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id$
+ * $Id: pj_utils.c,v 1.4 2005/07/06 14:04:09 fwarmerdam Exp $
  *
  * Project:  PROJ.4
  * Purpose:  Some utility functions we don't want to bother putting in
@@ -26,7 +26,23 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
- *****************************************************************************/
+ ******************************************************************************
+ *
+ * $Log: pj_utils.c,v $
+ * Revision 1.4  2005/07/06 14:04:09  fwarmerdam
+ * Improved precision of es encoding for pj_latlong_from_proj() per:
+ *   http://bugzilla.remotesensing.org/show_bug.cgi?id=881
+ *
+ * Revision 1.3  2002/12/14 20:14:00  warmerda
+ * added pj_is_geocent, added +pm support to pj_get_def
+ *
+ * Revision 1.2  2002/04/30 17:01:51  warmerda
+ * Removed printf() statement.
+ *
+ * Revision 1.1  2001/04/05 04:22:46  warmerda
+ * New
+ *
+ */
 
 #define PJ_LIB__
 
@@ -77,97 +93,84 @@ PJ *pj_latlong_from_proj( PJ *pj_in )
     pj_errno = 0;
     strcpy( defn, "+proj=latlong" );
 
-    if( pj_param(pj_in->ctx, pj_in->params, "tdatum").i )
+    if( pj_param(pj_in->params, "tdatum").i )
     {
         got_datum = TRUE;
         sprintf( defn+strlen(defn), " +datum=%s", 
-                 pj_param(pj_in->ctx, pj_in->params,"sdatum").s );
+                 pj_param(pj_in->params,"sdatum").s );
     }
-    else if( pj_param(pj_in->ctx, pj_in->params, "tellps").i )
+    else if( pj_param(pj_in->params, "tellps").i )
     {
         sprintf( defn+strlen(defn), " +ellps=%s", 
-                 pj_param(pj_in->ctx, pj_in->params,"sellps").s );
+                 pj_param(pj_in->params,"sellps").s );
     }
-    else if( pj_param(pj_in->ctx,pj_in->params, "ta").i )
+    else if( pj_param(pj_in->params, "ta").i )
     {
         sprintf( defn+strlen(defn), " +a=%s", 
-                 pj_param(pj_in->ctx,pj_in->params,"sa").s );
+                 pj_param(pj_in->params,"sa").s );
             
-        if( pj_param(pj_in->ctx,pj_in->params, "tb").i )
+        if( pj_param(pj_in->params, "tb").i )
             sprintf( defn+strlen(defn), " +b=%s", 
-                     pj_param(pj_in->ctx,pj_in->params,"sb").s );
-        else if( pj_param(pj_in->ctx,pj_in->params, "tes").i )
+                     pj_param(pj_in->params,"sb").s );
+        else if( pj_param(pj_in->params, "tes").i )
             sprintf( defn+strlen(defn), " +es=%s", 
-                     pj_param(pj_in->ctx,pj_in->params,"ses").s );
-        else if( pj_param(pj_in->ctx,pj_in->params, "tf").i )
+                     pj_param(pj_in->params,"ses").s );
+        else if( pj_param(pj_in->params, "tf").i )
             sprintf( defn+strlen(defn), " +f=%s", 
-                     pj_param(pj_in->ctx,pj_in->params,"sf").s );
+                     pj_param(pj_in->params,"sf").s );
         else
             sprintf( defn+strlen(defn), " +es=%.16g", 
                      pj_in->es );
     }
     else
     {
-        pj_ctx_set_errno( pj_in->ctx, -13 );
+        pj_errno = -13;
 
         return NULL;
     }
 
     if( !got_datum )
     {
-        if( pj_param(pj_in->ctx,pj_in->params, "ttowgs84").i )
+        if( pj_param(pj_in->params, "ttowgs84").i )
             sprintf( defn+strlen(defn), " +towgs84=%s", 
-                     pj_param(pj_in->ctx,pj_in->params,"stowgs84").s );
+                     pj_param(pj_in->params,"stowgs84").s );
 
-        if( pj_param(pj_in->ctx,pj_in->params, "tnadgrids").i )
+        if( pj_param(pj_in->params, "ttowgs84").i )
+            sprintf( defn+strlen(defn), " +towgs84=%s", 
+                     pj_param(pj_in->params,"stowgs84").s );
+
+        if( pj_param(pj_in->params, "tnadgrids").i )
             sprintf( defn+strlen(defn), " +nadgrids=%s", 
-                     pj_param(pj_in->ctx,pj_in->params,"snadgrids").s );
+                     pj_param(pj_in->params,"snadgrids").s );
     }
 
     /* copy over some other information related to ellipsoid */
-    if( pj_param(pj_in->ctx,pj_in->params, "tR").i )
+    if( pj_param(pj_in->params, "tR").i )
         sprintf( defn+strlen(defn), " +R=%s", 
-                 pj_param(pj_in->ctx,pj_in->params,"sR").s );
+                 pj_param(pj_in->params,"sR").s );
 
-    if( pj_param(pj_in->ctx,pj_in->params, "tR_A").i )
+    if( pj_param(pj_in->params, "tR_A").i )
         sprintf( defn+strlen(defn), " +R_A" );
 
-    if( pj_param(pj_in->ctx,pj_in->params, "tR_V").i )
+    if( pj_param(pj_in->params, "tR_V").i )
         sprintf( defn+strlen(defn), " +R_V" );
 
-    if( pj_param(pj_in->ctx,pj_in->params, "tR_a").i )
+    if( pj_param(pj_in->params, "tR_a").i )
         sprintf( defn+strlen(defn), " +R_a" );
 
-    if( pj_param(pj_in->ctx,pj_in->params, "tR_lat_a").i )
+    if( pj_param(pj_in->params, "tR_lat_a").i )
         sprintf( defn+strlen(defn), " +R_lat_a=%s", 
-                 pj_param(pj_in->ctx,pj_in->params,"sR_lat_a").s );
+                 pj_param(pj_in->params,"sR_lat_a").s );
 
-    if( pj_param(pj_in->ctx,pj_in->params, "tR_lat_g").i )
+    if( pj_param(pj_in->params, "tR_lat_g").i )
         sprintf( defn+strlen(defn), " +R_lat_g=%s", 
-                 pj_param(pj_in->ctx,pj_in->params,"sR_lat_g").s );
+                 pj_param(pj_in->params,"sR_lat_g").s );
 
     /* copy over prime meridian */
-    if( pj_param(pj_in->ctx,pj_in->params, "tpm").i )
+    if( pj_param(pj_in->params, "tpm").i )
         sprintf( defn+strlen(defn), " +pm=%s", 
-                 pj_param(pj_in->ctx,pj_in->params,"spm").s );
+                 pj_param(pj_in->params,"spm").s );
 
-    return pj_init_plus_ctx( pj_in->ctx, defn );
+    return pj_init_plus( defn );
 }
 
-/************************************************************************/
-/*                        pj_get_spheroid_defn()                        */
-/*                                                                      */
-/*      Fetch the internal definition of the spheroid.  Note that       */
-/*      you can compute "b" from eccentricity_squared as:               */
-/*                                                                      */
-/*      b = a * sqrt(1 - es)                                            */
-/************************************************************************/
-
-void pj_get_spheroid_defn(projPJ defn, double *major_axis, double *eccentricity_squared)
-{
-	if ( major_axis )
-		*major_axis = defn->a;
-		
-	if ( eccentricity_squared )
-		*eccentricity_squared = defn->es;
-};
